@@ -65,9 +65,12 @@ class WebServer(objects.Thread):
 		port=52379,
 		path=None,
 		default={},
+		# do not use.
+		serialized={},
 	):
 		objects.Thread.__init__(self)
 		self.__cache__ = Cache(path=path)
+		self.default = dict(default)
 		self.assign({
 			"sleeptime":3,
 			"id":id,
@@ -75,6 +78,9 @@ class WebServer(objects.Thread):
 			"port":port,
 			"cache":default,
 		})
+		self.assign(serialized)
+		self.id = id.replace(" ","-")
+		self.tag = self.id.replace(" ","_")
 	def set(self, group=None, id=None, data=None):
 		encoded = urllib.parse.urlencode({
 			"group":group,
@@ -180,13 +186,31 @@ class WebServer(objects.Thread):
 			return True
 		except requests.exceptions.ConnectionError:
 			return False
-		except requests.exceptions.NewConnectionError:
-			return False
 	def run(self):
 		self.__cache__.set(group=self.id, id="daemon", data="*running*")
 		self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
 		self.app()
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
+	def fork(self):
+		print(f"Starting the {self.id}.")
+		serialized = self.dict()
+		serialized["path"] = self.cache.path
+		for i in ["__cache__","cache",]:
+			del serialized[i]
+		p = subprocess.Popen(["python3", f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", {self.tag}])#, "2>", "/dev/null"])
+		time.sleep(3)
+	def stop(self):
+		if not self.running(): 
+			return r3sponse.error_response(f"The {self.id} is not running.")
+		processes = syst3m.processes(includes=f"--syst3m-webserver-tag {self.tag}")
+		if not processes.success: return response
+		if len(processes.processes) <= 1:
+			return r3sponse.error_response(f"Unable to find the pid of the {self.id}.")
+		for pid, info in processes.processes.items():
+			if info["process"] not in ["grep"]:
+				response = syst3m.kill(pid=pid)
+				if not response.success: return response
+		return r3sponse.error_response(f"Successfully stopped the {self.id}.")
 	def __serialize__(self, dict):
 		for key in list(dict.keys()):
 			value = dict[key]
